/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2013  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.88h                                            *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : Start_CpuLoad.c
Purpose : Skeleton program for OS
          Demonstrates usage of real time CPU load measurement
NOTES   : To get results, the OS_Idle() loop in RTOSInit may have
          to be modified, OS_INC_IDLE_CNT() has to be called:

          void OS_Idle(void) {
            while (1) {
              OS_INC_IDLE_CNT();
            }
          }

          The global variable OS_CPU_Load may be examined by a
          debugger with life watch capability

--------  END-OF-HEADER  ---------------------------------------------
*/

#include "RTOS.h"

OS_STACKPTR int StackHP[128], StackLP[128];          /* Task stacks */
OS_TASK TCBHP, TCBLP;                        /* Task-control-blocks */

static void HPTask(void) {
  while (1) {
    OS_Delay (10);
  }
}

static void LPTask(void) {
  volatile int Load;
  while (1) {
    OS_Delay (50);
    Load = OS_GetLoadMeasurement();
  }
}

/*********************************************************************
*
*       main
*
*********************************************************************/

int main(void) {
  OS_IncDI();                      /* Initially disable interrupts  */
  OS_InitKern();                   /* Initialize OS                 */
  OS_InitHW();                     /* Initialize Hardware for OS    */
  /* You need to create at least one task here !                    */
  OS_CREATETASK(&TCBHP, "HP Task", HPTask, 100, StackHP);
  OS_CREATETASK(&TCBLP, "LP Task", LPTask,  50, StackLP);
  //
  // Initialize CPU load measurement with 100 ticks period and auto-adjustment
  //
  OS_AddLoadMeasurement(100, 1, 0);
  OS_Start();                      /* Start multitasking            */
  return 0;
}

